@@ -7,10 +7,11 @@ Pure Python module to hyphenate text, inspired by Ruby's Text::Hyphen.
 
 """
 
-import os
 import re
+from importlib import resources
+from pathlib import Path
 
-VERSION = __version__ = '0.13.2'
+VERSION = __version__ = '0.16.0'
 
 __all__ = ('Pyphen', 'LANGUAGES', 'language_fallback')
 
@@ -20,24 +21,26 @@ hdcache = {}
 # precompile some stuff
 parse_hex = re.compile(r'\^{2}([0-9a-f]{2})').sub
 parse = re.compile(r'(\d?)(\D?)').findall
+ignored = (
+    '%', '#', 'LEFTHYPHENMIN', 'RIGHTHYPHENMIN',
+    'COMPOUNDLEFTHYPHENMIN', 'COMPOUNDRIGHTHYPHENMIN')
 
-try:
-    from pkg_resources import resource_filename
-    dictionaries_root = resource_filename('pyphen', 'dictionaries')
-except ImportError:
-    dictionaries_root = os.path.join(os.path.dirname(__file__), 'dictionaries')
-
-#: Dict of languages including codes as keys and dictionary path as values.
+#: Dict of languages including codes as keys and dictionary Path as values.
 LANGUAGES = {}
 
-for filename in sorted(os.listdir(dictionaries_root)):
-    if filename.endswith('.dic'):
-        name = filename[5:-4]
-        full_path = os.path.join(dictionaries_root, filename)
-        LANGUAGES[name] = full_path
+try:
+    dictionaries = resources.files('pyphen.dictionaries')
+except (AttributeError, TypeError):
+    # AttributeError with Python 3.8, TypeError with Python 3.9
+    dictionaries = Path(__file__).parent / 'dictionaries'
+
+for path in sorted(dictionaries.iterdir()):
+    if path.suffix == '.dic':
+        name = path.name[5:-4]
+        LANGUAGES[name] = path
         short_name = name.split('_')[0]
         if short_name not in LANGUAGES:
-            LANGUAGES[short_name] = full_path
+            LANGUAGES[short_name] = path
 
 LANGUAGES_LOWERCASE = {name.lower(): name for name in LANGUAGES}
 
@@ -59,7 +62,7 @@ def language_fallback(language):
         parts.pop()
 
 
-class AlternativeParser(object):
+class AlternativeParser:
     """Parser of nonstandard hyphen pattern alternative.
 
     The instance returns a special int with data about the current position in
@@ -100,56 +103,54 @@ class DataInt(int):
         return obj
 
 
-class HyphDict(object):
+class HyphDict:
     """Hyphenation patterns."""
 
-    def __init__(self, filename):
+    def __init__(self, path):
         """Read a ``hyph_*.dic`` and parse its patterns.
 
-        :param filename: filename of hyph_*.dic to read
+        :param path: Path of hyph_*.dic to read
 
         """
         self.patterns = {}
 
-        with open(filename, 'rb') as stream:
-            # see "man 4 hunspell", iscii-devanagari is not supported by python
-            charset = stream.readline().strip().decode('ascii')
-            if charset.lower() == 'microsoft-cp1251':
-                charset = 'cp1251'
-            for pattern in stream:
-                pattern = pattern.decode(charset).strip()
-                if not pattern or pattern.startswith((
-                        '%', '#', 'LEFTHYPHENMIN', 'RIGHTHYPHENMIN',
-                        'COMPOUNDLEFTHYPHENMIN', 'COMPOUNDRIGHTHYPHENMIN')):
-                    continue
+        # see "man 4 hunspell", iscii-devanagari is not supported by python
+        with path.open('rb') as fd:
+            encoding = fd.readline().decode()
+        if encoding.lower() == 'microsoft-cp1251':
+            encoding = 'cp1251'
 
-                # replace ^^hh with the real character
-                pattern = parse_hex(
-                    lambda match: chr(int(match.group(1), 16)), pattern)
+        for pattern in path.read_text(encoding).split('\n')[1:]:
+            pattern = pattern.strip()
+            if not pattern or pattern.startswith(ignored):
+                continue
 
-                # read nonstandard hyphen alternatives
-                if '/' in pattern and '=' in pattern:
-                    pattern, alternative = pattern.split('/', 1)
-                    factory = AlternativeParser(pattern, alternative)
-                else:
-                    factory = int
+            # replace ^^hh with the real character
+            pattern = parse_hex(
+                lambda match: chr(int(match.group(1), 16)), pattern)
 
-                tags, values = zip(*[
-                    (string, factory(i or '0'))
-                    for i, string in parse(pattern)])
+            # read nonstandard hyphen alternatives
+            if '/' in pattern and '=' in pattern:
+                pattern, alternative = pattern.split('/', 1)
+                factory = AlternativeParser(pattern, alternative)
+            else:
+                factory = int
 
-                # if only zeros, skip this pattern
-                if max(values) == 0:
-                    continue
+            tags, values = zip(*[
+                (string, factory(i or '0')) for i, string in parse(pattern)])
 
-                # chop zeros from beginning and end, and store start offset
-                start, end = 0, len(values)
-                while not values[start]:
-                    start += 1
-                while not values[end - 1]:
-                    end -= 1
+            # if only zeros, skip this pattern
+            if max(values) == 0:
+                continue
 
-                self.patterns[''.join(tags)] = start, values[start:end]
+            # chop zeros from beginning and end, and store start offset
+            start, end = 0, len(values)
+            while not values[start]:
+                start += 1
+            while not values[end - 1]:
+                end -= 1
+
+            self.patterns[''.join(tags)] = start, values[start:end]
 
         self.cache = {}
         self.maxlen = max(len(key) for key in self.patterns)
@@ -183,27 +184,26 @@ class HyphDict(object):
         word = word.lower()
         points = self.cache.get(word)
         if points is None:
-            pointed_word = '.%s.' % word
+            pointed_word = f'.{word}.'
             references = [0] * (len(pointed_word) + 1)
 
             for i in range(len(pointed_word) - 1):
-                for j in range(
-                        i + 1, min(i + self.maxlen, len(pointed_word)) + 1):
+                stop = min(i + self.maxlen, len(pointed_word)) + 1
+                for j in range(i + 1, stop):
                     pattern = self.patterns.get(pointed_word[i:j])
-                    if pattern:
-                        offset, values = pattern
-                        slice_ = slice(i + offset, i + offset + len(values))
-                        references[slice_] = map(
-                            max, values, references[slice_])
+                    if not pattern:
+                        continue
+                    offset, values = pattern
+                    slice_ = slice(i + offset, i + offset + len(values))
+                    references[slice_] = map(max, values, references[slice_])
 
-            points = [
+            self.cache[word] = points = [
                 DataInt(i - 1, reference=reference)
                 for i, reference in enumerate(references) if reference % 2]
-            self.cache[word] = points
         return points
 
 
-class Pyphen(object):
+class Pyphen:
     """Hyphenation class, with methods to hyphenate strings in various ways."""
 
     def __init__(self, filename=None, lang=None, left=2, right=2, cache=True):
@@ -283,7 +283,7 @@ class Pyphen(object):
         given as the second parameter, that defaults to ``'-'``.
 
         """
-        word_list = list(word)
+        letters = list(word)
         for position in reversed(self.positions(word)):
             if position.data:
                 # get the nonstandard hyphenation data
@@ -291,10 +291,10 @@ class Pyphen(object):
                 index += position
                 if word.isupper():
                     change = change.upper()
-                word_list[index:index + cut] = change.replace('=', hyphen)
+                letters[index:index + cut] = change.replace('=', hyphen)
             else:
-                word_list.insert(position, hyphen)
+                letters.insert(position, hyphen)
 
-        return ''.join(word_list)
+        return ''.join(letters)
 
     __call__ = iterate
